@@ -1,5 +1,5 @@
 /*
-cromfs - Copyright (C) 1992,2009 Bisqwit (http://iki.fi/bisqwit/)
+cromfs - Copyright (C) 1992,2014 Bisqwit (http://iki.fi/bisqwit/)
 Licence: GPL3
 
 cromfs.cc: The cromfs filesystem engine.
@@ -30,12 +30,12 @@ See doc/FORMAT for the documentation of the filesystem structure.
 #include <sys/stat.h>
 
 extern "C" {
-#include "lib/lzma/C/LzmaDec.h"
+#include "lib/lzma/C/LzmaDec.h" /* For LZMA_PROPS_SIZE */
 }
 
 #include "lib/longfileread.hh"
-#include "lib/cromfs-blockfun.hh"
 #include "lib/cromfs-inodefun.hh"
+#include "lib/cromfs-blockfun.hh"
 #include "lib/fadvise.hh"
 #include "lib/util.hh"
 #include "cromfs.hh"
@@ -83,7 +83,7 @@ static const std::vector<unsigned char> LZMADeCompress
         return std::vector<unsigned char> ();
     }
 
-    uint_least64_t out_sizemax = R64(&buf[LZMA_PROPS_SIZE]);
+    uint_least64_t out_sizemax = get_64(&buf[LZMA_PROPS_SIZE]);
 
     if(out_sizemax >= (size_t)~0ULL)
     {
@@ -200,14 +200,14 @@ void cromfs::reread_superblock()
 
 #if SBLOCK_DEBUG
     fprintf(stderr,
-        "Superblock signature %llX\n"
-        "BlockTab at 0x%llX\n"
-        "FBlkTab at 0x%llX\n"
-        "inotab at 0x%llX (size 0x%llX)\n"
-        "rootdir at 0x%llX (size 0x%llX)\n"
+        "Superblock signature %"LL_FMT"X\n"
+        "BlockTab at 0x%"LL_FMT"X\n"
+        "FBlkTab at 0x%"LL_FMT"X\n"
+        "inotab at 0x%"LL_FMT"X (size 0x%"LL_FMT"X)\n"
+        "rootdir at 0x%"LL_FMT"X (size 0x%"LL_FMT"X)\n"
         "FSIZE %u  BSIZE %u\n"
         "%u fblocks, %u blocks\n"
-        "%llu bytes of files\n",
+        "%"LL_FMT"u bytes of files\n",
         (unsigned long long)sblock.sig,
         (unsigned long long)sblock.blktab_offs,
         (unsigned long long)sblock.fblktab_offs,
@@ -306,28 +306,25 @@ void cromfs::reread_fblktab()
 {
     fblktab.clear();
 
+    uint_fast64_t eofpos   = lseek64(fd, 0, SEEK_END);
     uint_fast64_t startpos = sblock.fblktab_offs;
-    for(;;)
+    while(startpos + (4+LZMA_PROPS_SIZE+8) < eofpos)
     {
-        unsigned char Buf[17];
-        /* TODO: LongFileRead here... but catch EOF somehow? */
-        ssize_t r = pread64(fd, Buf, 17, startpos);
-        if(r == 0) break;
-        if(r < 0) throw errno;
-        if(r < 17) throw EINVAL;
+        LongFileRead fbreader(fd, startpos, 4+LZMA_PROPS_SIZE+8);
+        const unsigned char* Buf = fbreader.GetAddr();
 
         cromfs_fblock_internal fblock;
         fblock.filepos = startpos+4;
-        fblock.length  = R32(Buf);
-        //uint_fast64_t orig_length = R64(Buf+9); // <- not interesting
+        fblock.length  = get_32(Buf);
+        //uint_fast64_t orig_length = get_64(Buf+9); // <- not interesting
 
-        if(fblock.length <= 13)
+        if(fblock.length <= LZMA_PROPS_SIZE+8)
         {
             throw EINVAL;
         }
 
 #if FBLOCK_DEBUG
-        fprintf(stderr, "FBLOCK %u: size(%u)at(%llu (0x%llX))\n",
+        fprintf(stderr, "FBLOCK %u: size(%u)at(%"LL_FMT"u (0x%"LL_FMT"X))\n",
             (unsigned)fblktab.size(),
             (unsigned)fblock.length,
             (unsigned long long)fblock.filepos,
@@ -471,7 +468,7 @@ cromfs_inode_internal cromfs::read_special_inode
             get_inode_header(Buf, 0x18, inode, 0, CROMFS_BSIZE);
 
 #if INODE_DEBUG
-            printf("read_special_inode(%lld): %s\n",
+            printf("read_special_inode(%"LL_FMT"d): %s\n",
                 (long long)offset,
                 DumpInode(inode).c_str());
 #endif
@@ -483,7 +480,7 @@ cromfs_inode_internal cromfs::read_special_inode
 
                 LongFileRead reader(fd, offset+0x18, 4*nblocks);
                 for(unsigned n=0; n<nblocks; ++n)
-                    inode.blocklist[n] = R32(reader.GetAddr() + n*4);
+                    inode.blocklist[n] = get_32(reader.GetAddr() + n*4);
             }
         }
     }
@@ -510,7 +507,7 @@ const cromfs_inode_internal cromfs::read_inode(cromfs_inodenum_t inodenum)
     get_inode_header(Buf, INODE_HEADER_SIZE(), inode, storage_opts, CROMFS_BSIZE);
 
 #if INODE_DEBUG
-    fprintf(stderr, "returning inode %llu: %s\n",
+    fprintf(stderr, "returning inode %"LL_FMT"u: %s\n",
         (unsigned long long)inodenum,
         DumpInode(inode).c_str());
 #endif
@@ -537,7 +534,7 @@ const cromfs_inode_internal cromfs::read_inode_and_blocks(cromfs_inodenum_t inod
 
     uint_fast64_t nblocks = CalcSizeInBlocks(result.bytesize, result.blocksize);
 
-    //fprintf(stderr, "%llu bytes: %llu blocks\n",
+    //fprintf(stderr, "%"LL_FMT"u bytes: %"LL_FMT"u blocks\n",
     //    (unsigned long long)result.bytesize, (unsigned long long)nblocks);
 
     uint_fast64_t inode_blocktable_offset = GetInodeOffset(inodenum) + INODE_HEADER_SIZE();
@@ -559,7 +556,7 @@ const cromfs_inode_internal cromfs::read_inode_and_blocks(cromfs_inodenum_t inod
                        "inode block table");
 
         for(unsigned n=0; n<nblocks; ++n)
-            result.blocklist[n] = Rn(&blocklist[n * b], b);
+            result.blocklist[n] = get_n(&blocklist[n * b], b);
     }
     else
     {
@@ -569,7 +566,7 @@ const cromfs_inode_internal cromfs::read_inode_and_blocks(cromfs_inodenum_t inod
 
         /* Fix endianess after raw read */
         for(unsigned n=0; n<nblocks; ++n)
-            result.blocklist[n] = R32(&result.blocklist[n]);
+            result.blocklist[n] = get_32(&result.blocklist[n]);
     }
 
     return result;
@@ -636,7 +633,7 @@ cromfs_cached_fblock cromfs::read_fblock_uncached(cromfs_fblocknum_t fblocknum)
     const uint_fast64_t filepos   = fblktab[fblocknum].filepos;
 
 #if FBLOCK_DEBUG
-    fprintf(stderr, "- - - - reading fblock %u (%u bytes) from %llu\n",
+    fprintf(stderr, "- - - - reading fblock %u (%u bytes) from filepos = %"LL_FMT"u\n",
         (unsigned)fblocknum, (unsigned)comp_size,
         (unsigned long long)filepos);
 #endif
@@ -651,7 +648,7 @@ int_fast64_t cromfs::read_file_data(
     throw (cromfs_exception, std::bad_alloc)
 {
     return read_file_data(
-        inonum==1 ? get_root_inode () : read_inode_and_blocks(inonum),
+        inonum==0 ? inotab : read_inode_and_blocks(inonum),
         offset, target, size, purpose);
 }
 
@@ -698,7 +695,7 @@ int_fast64_t cromfs::read_file_data_from_one_fblock_only(
 
 #if READFILE_DEBUG >= 2
         fprintf(stderr,
-            "- File offset %llu (block %u(b%u f%u) @%u, consume %llu bytes of %llu) -> %p\n",
+            "- File offset %"LL_FMT"u (block %u(b%u f%u) @%u, consume %"LL_FMT"u bytes of %"LL_FMT"u) -> %p\n",
                 (unsigned long long)offset,
                 (unsigned)begin_block_index,
                 (unsigned)blocknum,
@@ -751,7 +748,7 @@ int_fast64_t cromfs::read_file_data(
 {
 #if READFILE_DEBUG
     fprintf(stderr,
-        "read_file_data, offset=%llu, target=%p, size=%llu = %s\n",
+        "read_file_data, offset=%"LL_FMT"u, target=%p, size=%"LL_FMT"u = %s\n",
         (unsigned long long)offset,
         target,
         (unsigned long long)size,
@@ -926,7 +923,7 @@ const cromfs_dirinfo cromfs::read_dir(cromfs_inodenum_t inonum,
         //fprintf(stderr, "GORE!!! 3\n");
         throw EIO;
     }
-    uint_fast32_t num_files = R32(DirHeader);
+    uint_fast32_t num_files = get_32(DirHeader);
 
 #if READDIR_DEBUG
     fprintf(stderr, "read_dir(%s)(%u,%u): num_files=%u\n",
@@ -963,7 +960,7 @@ const cromfs_dirinfo cromfs::read_dir(cromfs_inodenum_t inonum,
 
             /* Fix endianess after raw read */
             for(unsigned n=0; n<num_addrs_to_read; ++n)
-                entry_offsets[n] = R32(&entry_offsets[n]);
+                entry_offsets[n] = get_32(&entry_offsets[n]);
 
             const unsigned name_buf_size = entry_offsets[num_to_read] - entry_offsets[0];
             std::vector<unsigned char> name_buf(name_buf_size);
@@ -997,7 +994,7 @@ const cromfs_dirinfo cromfs::read_dir(cromfs_inodenum_t inonum,
 
                 const unsigned char* name_data = &name_buf[name_offs];
 
-                uint_fast64_t inonumber   = R64(&name_data[0]);
+                uint_fast64_t inonumber   = get_64(&name_data[0]);
                 const unsigned char* filename = &name_data[8];
 
                 /* The name must be terminated by a nul pointer. */
@@ -1053,7 +1050,7 @@ cromfs_inodenum_t cromfs::dir_lookup(cromfs_inodenum_t inonum,
         //fprintf(stderr, "GORE!!! 3\n");
         throw EIO;
     }
-    uint_fast32_t num_files = R32(DirHeader);
+    uint_fast32_t num_files = get_32(DirHeader);
 
     std::vector<uint_least32_t> entry_offsets(num_files+1);
     std::vector<bool>           offs_read(num_files);
@@ -1068,7 +1065,7 @@ cromfs_inodenum_t cromfs::dir_lookup(cromfs_inodenum_t inonum,
     /* Fix endianess after raw read */
     for(unsigned n=0; n<num_files; ++n)
     {
-        entry_offsets[n] = R32(&entry_offsets[n]);
+        entry_offsets[n] = get_32(&entry_offsets[n]);
         offs_read[n] = true;
     }
 #endif
@@ -1097,12 +1094,12 @@ cromfs_inodenum_t cromfs::dir_lookup(cromfs_inodenum_t inonum,
                                "dir offset list");
                 if(read_offs == 0)
                 {
-                    entry_offsets[middle] = R32(&entry_offsets[middle]);
+                    entry_offsets[middle] = get_32(&entry_offsets[middle]);
                     offs_read[middle] = true;
                 }
                 if(n_read == 8 || read_offs == 4)
                 {
-                    entry_offsets[middle+1] = R32(&entry_offsets[middle+1]);
+                    entry_offsets[middle+1] = get_32(&entry_offsets[middle+1]);
                     offs_read[middle+1] = true;
                 }
             }
@@ -1127,7 +1124,7 @@ cromfs_inodenum_t cromfs::dir_lookup(cromfs_inodenum_t inonum,
                        entry_buf.size(),
                        "dir entry");
 
-        uint_fast64_t inonumber   = R64(&entry_buf[0]);
+        uint_fast64_t inonumber   = get_64(&entry_buf[0]);
         const unsigned char* filename = &entry_buf[8];
 
         /* The name must be terminated by a nul pointer. */
