@@ -40,7 +40,7 @@ static void DisplayProgress(
     const char* suffix = "")
 {
     char Buf[4096];
-    std::sprintf(Buf, "%s: %5.2f%% (%llu/%llu)%s",
+    std::sprintf(Buf, "%s: %5.2f%% (%"LL_FMT"u/%"LL_FMT"u)%s",
         label,
         pos
         * 100.0
@@ -241,7 +241,7 @@ static void FindOverlap(
         return;
     }
 
-    if(AutoIndexPeriod == 1 && BSIZE == data.size())
+    if(AutoIndexPeriod == 1 && (size_t)BSIZE == data.size())
     {
         // If autoindexperiod covers all possible full overlaps,
         // then we need to only search for appends.
@@ -711,9 +711,11 @@ void cromfs_blockifier::SpecialAutoIndex(const cromfs_fblocknum_t fblocknum)
      * identical block detection.
      */
 
+#if 0
     const mkcromfs_fblock& fblock = fblocks[fblocknum];
+#endif
 
-#if 1 /* NES indexing */
+#if 0 /* NES indexing */
     {
         static const unsigned char NES_SIG[4] = {'N','E','S',0x1A};
         static const BoyerMooreNeedle nes_needle(NES_SIG, 4);
@@ -751,7 +753,7 @@ void cromfs_blockifier::SpecialAutoIndex(const cromfs_fblocknum_t fblocknum)
     }
 #endif
 
-#if 1 /* GameBoy indexing */
+#if 0 /* GameBoy indexing */
     {
         static const unsigned char GB_SIG[4] = {0xCE,0xED,0x66,0x66};
         static const BoyerMooreNeedle gb_needle(GB_SIG, 4);
@@ -864,10 +866,15 @@ template<typename schedule_item, size_t max_open>
 class schedule_cache
 {
     std::vector<schedule_item>& schedule;
+#ifndef WIN32
     typedef
         std::list<size_t,
             FSBAllocator<size_t>
                  > open_list_t;
+#else
+    // Microsoft STL errors here if FSBAllocator is used.
+    typedef std::list<size_t> open_list_t;
+#endif
     open_list_t open_list;
     size_t n_open;
     MutexType lock;
@@ -992,9 +999,9 @@ static void VerifyInodeIntact(
     bool has_variable_blocksizes = storage_opts & CROMFS_OPT_VARIABLE_BLOCKSIZES;
 
     const unsigned char* inodeheader = blockdata_begin - INODE_HEADER_SIZE();
-    const uint_fast32_t inomode    = R32(inodeheader+0x00);
-    const uint_fast64_t inolength  = R64(inodeheader+0x10);
-    const uint_fast32_t inoblksize = has_variable_blocksizes ? R32(inodeheader+0x18) : blocksize;
+    const uint_fast32_t inomode    = get_32(inodeheader+0x00);
+    const uint_fast64_t inolength  = get_64(inodeheader+0x10);
+    const uint_fast32_t inoblksize = has_variable_blocksizes ? get_32(inodeheader+0x18) : blocksize;
     const long calc_bsize = CalcBSIZEfor(name);
 
     const void* inodehdr = (const void*)inodeheader;
@@ -1180,7 +1187,8 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
 
         DataReadBuffer buf;
         #pragma omp parallel for schedule(guided) private(buf) shared(n_unique,n_collisions)
-        for(size_t a=0; a < schedule.size(); ++a)
+        //for(size_t a=0; a < schedule.size(); ++a)
+        for(long a=0; a < (long)schedule.size(); ++a) // use "long" so ICC 10.0 won't complain
         {
             schedule_item& s = schedule[a];
             datasource_t* source  = s.GetDataSource();
@@ -1190,7 +1198,7 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
 
             if(DisplayBlockSelections)
             {
-                std::printf("%s <size %llu, block size %llu>\n",
+                std::printf("%s <size %"LL_FMT"u, block size %"LL_FMT"u>\n",
                     source->getname().c_str(),
                     (unsigned long long)nbytes,
                     (unsigned long long)blocksize);
@@ -1313,7 +1321,7 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
 
             if(DisplayBlockSelections)
             {
-                std::printf("%s <size %llu, block size %llu>\n",
+                std::printf("%s <size %"LL_FMT"u, block size %"LL_FMT"u>\n",
                     source->getname().c_str(),
                     (unsigned long long)nbytes,
                     (unsigned long long)blocksize);
@@ -1345,7 +1353,7 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
                 if(offset+eat > nbytes) eat = nbytes-offset;
 
                 /*
-                std::printf("Eating %llu bytes @ %llu",
+                std::printf("Eating %"LL_FMT"u bytes @ %"LL_FMT"u",
                     (unsigned long long) eat,
                     (unsigned long long) offset);
                 */
@@ -1524,7 +1532,7 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
                                 // It is an exact match.
                                 if(identical_lock.TryLock())
                                 {
-                                    //std::printf("... matches block %llu\n", (unsigned long long)other);
+                                    //std::printf("... matches block %"LL_FMT"u\n", (unsigned long long)other);
                                     #pragma omp flush(identical_found)
                                     if(!identical_found)
                                     {
@@ -1623,7 +1631,7 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
                                     // It is an exact match.
                                     if(identical_lock.TryLock())
                                     {
-                                        //std::printf("... matches block %llu\n", (unsigned long long)other);
+                                        //std::printf("... matches block %"LL_FMT"u\n", (unsigned long long)other);
                                         #pragma omp flush(identical_found)
                                         if(!identical_found)
                                         {
@@ -1709,12 +1717,13 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
             unsigned char* target = s.GetBlockTarget();
             uint_fast64_t nbytes  = source->size();
             uint_fast64_t blocksize = s.GetBlockSize();
+        #ifndef NDEBUG
             unsigned char* target_end =
                 target + BLOCKNUM_SIZE_BYTES() * ((nbytes + blocksize-1) / blocksize);
-
+        #endif
             if(DisplayBlockSelections)
             {
-                std::printf("%s <size %llu, block size %llu>\n",
+                std::printf("%s <size %"LL_FMT"u, block size %"LL_FMT"u>\n",
                     source->getname().c_str(),
                     (unsigned long long)nbytes,
                     (unsigned long long)blocksize);
@@ -1726,12 +1735,14 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
             //printf("rangebegin %p\nrange  end %p...\n", target, target_end);
             for(uint_fast64_t offset=0; offset<nbytes; offset += blocksize)
             {
+            #ifndef NDEBUG
                 assertbegin();
                 const void* tgt_next = (const void*)(target + BLOCKNUM_SIZE_BYTES());
                 const void* tgt_end  = (const void*)target_end;
                 assert2var(tgt_next, tgt_end);
                 assert(tgt_next <= tgt_end);
                 assertflush();
+            #endif
 
                 if(DisplayBlockSelections
                 || total_done - last_report_pos >= 1048576*4) // at 4 MB intervals
@@ -1785,10 +1796,10 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
 
                     // Find the blocknumber
                     uint_fast64_t blockindex2 = filepos / blocksize2;
-                    uint_fast64_t blocknum = Rn(target2 + blockindex2 * BLOCKNUM_SIZE_BYTES(), BLOCKNUM_SIZE_BYTES());
+                    uint_fast64_t blocknum = get_n(target2 + blockindex2 * BLOCKNUM_SIZE_BYTES(), BLOCKNUM_SIZE_BYTES());
                     // Write the blocknumber here
                     //printf("writing to %p (%u)...\n", target, BLOCKNUM_SIZE_BYTES());
-                    Wn(target, blocknum, BLOCKNUM_SIZE_BYTES());
+                    put_n(target, blocknum, BLOCKNUM_SIZE_BYTES());
                 #if 0
                     assertbegin();
                     assert8var(blocknum, blocks_done,other, blocks.size(), filepos, blocksize2, blocksize, blockindex2);
@@ -1804,8 +1815,8 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
                     {
                         std::fprintf(stderr,
                             "Invalid reuse indication %lu = %lu. Not identical %u bytes:\n"
-                            "1: Position%14llu in %s\n"
-                            "2: Position%14llu in %s\n",
+                            "1: Position%14"LL_FMT"u in %s\n"
+                            "2: Position%14"LL_FMT"u in %s\n",
                             (unsigned long) blocks_done,
                             (unsigned long) other,
                             (unsigned) eat,
@@ -1843,7 +1854,7 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
                     {
                         cromfs_blocknum_t blocknum = Execute(reuse, eat);
                         //printf("writing to %p (%u)...\n", target, BLOCKNUM_SIZE_BYTES());
-                        Wn(target, blocknum, BLOCKNUM_SIZE_BYTES());
+                        put_n(target, blocknum, BLOCKNUM_SIZE_BYTES());
                     }
                     else
                     {
@@ -1854,7 +1865,7 @@ void cromfs_blockifier::FlushBlockifyRequests(const char* purpose)
                         cromfs_blocknum_t blocknum = Execute(write);
 
                         //printf("writing to %p (%u)...\n", target, BLOCKNUM_SIZE_BYTES());
-                        Wn(target, blocknum, BLOCKNUM_SIZE_BYTES());
+                        put_n(target, blocknum, BLOCKNUM_SIZE_BYTES());
                     }
                 }
                 target += BLOCKNUM_SIZE_BYTES(); // where block number will be written to.
