@@ -153,7 +153,9 @@ namespace cromfs_creator
         }
     }
 
-    static void FinalCompressFblock(cromfs_fblocknum_t fblocknum,
+    static void FinalCompressFblock(
+        cromfs_fblocknum_t fblocknum,
+        cromfs_fblocknum_t fblockcount,
         mkcromfs_fblock& fblock,
         uint_fast64_t& compressed_total,
         uint_fast64_t& uncompressed_total)
@@ -181,8 +183,8 @@ namespace cromfs_creator
 
         if(DisplayEndProcess)
         {
-            std::printf(" [%d] %u -> %u\n",
-                (int)fblocknum,
+            std::printf(" [%ld/%ld] %u -> %u\n",
+                (long)fblocknum, (long)fblockcount,
                 (unsigned)fblock_rawlength,
                 (unsigned)fblock_lzma.size());
             std::fflush(stdout);
@@ -336,9 +338,12 @@ namespace cromfs_creator
 
     #ifdef USE_RECURSIVE_OMP_READDIR
       {
-        int dirent_len = offsetof(dirent, d_name) + pathconf(path.c_str(), _PC_NAME_MAX) + 1;
-        std::vector<char> dirent_buf(dirent_len);
+        struct dirent dummy;
+        int dirent_len = ((char*)(&dummy.d_name) - (char*)(&dummy))
+                       + pathconf(path.c_str(), _PC_NAME_MAX)
+                       + 1;
         dirent* dent = 0;
+        std::vector<char> dirent_buf(dirent_len);
         while(readdir_r(dir, (dirent*)&dirent_buf[0], &dent)==0 && dent)
             dnames.push_back(dent->d_name);
       }
@@ -408,11 +413,13 @@ namespace cromfs_creator
        (const std::string& path,
         // Collection and result_dirinfo are made pointers instead
         // of references so that they can be used in omp task.
-        dircollection* const collection,
-        cromfs_dirinfo* const result_dirinfo)
+        dircollection* collection,
+        cromfs_dirinfo* result_dirinfo)
     {
         // Step 1: Scan the contents of this directory.
         //         Ignore entries which were not wanted (through MatchFile).
+        assert(result_dirinfo);
+        assert(collection);
 
     #ifdef USE_RECURSIVE_OMP_READDIR
         dircollection tmpcollection;
@@ -454,7 +461,7 @@ namespace cromfs_creator
         for(size_t p=collection_begin_pos; p<collection_end_pos; ++p)
         {
         #ifdef USE_RECURSIVE_OMP_READDIR
-          #pragma omp task firstprivate(p) shared(path)
+          #pragma omp task default(none) firstprivate(p,collection,result_dirinfo) shared(path)
           {
         #endif
             uint_fast64_t bytesize = 0;
@@ -662,7 +669,7 @@ namespace cromfs_creator
             if(DisplayFiles)
             {
                 std::printf(
-                    "%s ... inode %ld. Size %llu"
+                    "%s ... inode %ld. Size %"LL_FMT"u"
                 #ifndef NDEBUG
                     ", Spans from %p..%p"
                 #endif
@@ -738,8 +745,10 @@ namespace cromfs_creator
             }
 
             assertbegin();
+            #ifndef NDEBUG
             assert4var(num_blocks, inode.blocklist.size(), ent.bytesize, inode.bytesize);
             assert(num_blocks   == inode.blocklist.size());
+            #endif
             assert(ent.bytesize == inode.bytesize);
             assertflush();
 
@@ -916,7 +925,7 @@ namespace cromfs_creator
 
                 // Poke in the storage opts again, because storage_opts may have
                 // been changed since the last write due to EnablePackedBlocks.
-                W32(&raw_inotab_inode[0], storage_opts);
+                put_32(&raw_inotab_inode[0], storage_opts);
 
                 std::fflush(stdout);
 
@@ -993,10 +1002,10 @@ namespace cromfs_creator
         {
         SparseWrite(out_fd, Superblock, sblock.GetSize(), 0); }
         #pragma omp section
-        { //fprintf(stderr, "root goes at %llX\n", sblock.rootdir_offs);
+        { //fprintf(stderr, "root goes at %"LL_FMT"X\n", sblock.rootdir_offs);
         SparseWrite(out_fd, &compressed_root_inode[0],   compressed_root_inode.size(), sblock.rootdir_offs); }
         #pragma omp section
-        { //fprintf(stderr, "inotab goes at %llX\n", sblock.inotab_offs);
+        { //fprintf(stderr, "inotab goes at %"LL_FMT"X\n", sblock.inotab_offs);
         SparseWrite(out_fd, &compressed_inotab_inode[0], compressed_inotab_inode.size(), sblock.inotab_offs); }
         #pragma omp section
         { SparseWrite(out_fd, &compressed_blktab[0], compressed_blktab.size(), sblock.blktab_offs); }
@@ -1038,10 +1047,11 @@ namespace cromfs_creator
          * and cromfs_fblocknum_t is unsigned.
          */
 
+        cromfs_fblocknum_t fblockcount = fblocks.size();
       #pragma omp parallel for ordered schedule(dynamic) \
             reduction(+:compressed_total) \
             reduction(+:uncompressed_total)
-        for(long/*cromfs_fblocknum_t*/ fblocknum=0; fblocknum<(long)fblocks.size(); ++fblocknum)
+        for(long/*cromfs_fblocknum_t*/ fblocknum=0; fblocknum<(long)fblockcount; ++fblocknum)
         {
           #ifdef _OPENMP
             omp_set_num_threads(backup_max_threads);
@@ -1051,7 +1061,8 @@ namespace cromfs_creator
 
           #pragma omp flush(terminate_for)
             if(!terminate_for)
-                FinalCompressFblock(fblocknum, fblock, compressed_total, uncompressed_total);
+                FinalCompressFblock(fblocknum,fblockcount,
+                                    fblock, compressed_total, uncompressed_total);
 
           #pragma omp ordered
           {
@@ -1077,7 +1088,7 @@ namespace cromfs_creator
             }
 
             { unsigned char Buf[64];
-              W32(Buf, lzma_length);
+              put_32(Buf, lzma_length);
               SparseWrite(out_fd, Buf, 4, fblk_offset);
               fblk_offset += 4;
             }
@@ -1184,7 +1195,7 @@ namespace cromfs_creator
                 unsigned char SizeBuffer[4];
                 LongFileRead(out_fd, fblock_pos, 4, SizeBuffer);
 
-                uint_fast64_t fblock_lzma_size = R32(SizeBuffer);
+                uint_fast64_t fblock_lzma_size = get_32(SizeBuffer);
 
                 std::vector<unsigned char> fblockdata(fblock_lzma_size);
 
@@ -1222,7 +1233,7 @@ namespace cromfs_creator
                 {
                     std::printf(" it existed, compressing...\n");
                     uint_fast64_t com=0, uncom=0;
-                    FinalCompressFblock(fblocknum, fblock, com, uncom);
+                    FinalCompressFblock(fblocknum,-1/*fblocks.size()*/, fblock, com, uncom);
                 }
 
                 DataReadBuffer lzma_buffer;
@@ -1235,7 +1246,7 @@ namespace cromfs_creator
                     (unsigned long)fblock_pos);
 
                 { unsigned char SizeBuffer[64];
-                  W32(SizeBuffer, lzma_length);
+                  put_32(SizeBuffer, lzma_length);
                   LongFileWrite(out_fd, fblock_pos, 4, SizeBuffer); }
 
                 SparseWrite(out_fd, lzma_buffer.Buffer, lzma_length, fblock_pos+4);
@@ -1570,7 +1581,7 @@ int main(int argc, char** argv)
             case 'h':
             {
                 std::printf(
-                    "mkcromfs v"VERSION" - Copyright (C) 1992,2009 Bisqwit (http://iki.fi/bisqwit/)\n"
+                    "mkcromfs v"VERSION" - Copyright (C) 1992,2014 Bisqwit (http://iki.fi/bisqwit/)\n"
                     "\n"
                     "Usage: mkcromfs [<options>] <input_path> <target_image>\n"
                     "\n"
@@ -2266,6 +2277,12 @@ int main(int argc, char** argv)
         std::printf("Writing %s...\n", outfn.c_str());
     }
 
+    if(access( (path + "/.").c_str(), R_OK) < 0)
+    {
+        perror(path.c_str());
+        return errno;
+    }
+
     int fd = open(outfn.c_str(), O_RDWR | O_CREAT | O_LARGEFILE, 0644);
     if(fd < 0)
     {
